NeMo ASR Collection: Neural Modules for Automatic Speech Recognition
====================================================================

**Models**

The NeMo ASR collection currently has modules for building
1. All Jasper convolutional models:
..* Jasper DR 10x5
..* Jasper 15x5 Seperable
..* Jasper Mini
2. Jasper Encoder + Seq2seq Decoder

See the documentation and tutorials for ``nemo_asr`` [here](https://nvidia.github.io/NeMo/asr/intro.html).